@@ -4,3 +4,7 @@ from . import bit, core, renderers
 
 def use_text_renderer():
     bit.RENDERER = renderers.TextRenderer
+
+
+def use_last_frame_renderer():
+    bit.RENDERER = renderers.LastFrameRenderer
